@@ -102,7 +102,7 @@ sub upload {
 	    : 'media';
     }
 
-    my $self = $class->_insert_class($insert_data, %opt);
+    my $self = $class->insert($insert_data, %opt);
 
     if ($length) {
 
@@ -199,9 +199,9 @@ sub import_from_server {
 
     $opt{param}{fileName} = $filename;
 
-    $class->_insert_class($insert_data,
-			  adapter => 'importPreload',
-			  %opt);
+    $class->insert($insert_data,
+		   adapter => 'importPreload',
+		   %opt);
 }
 
 =head2 list_meeting_preloads
